@@ -7,10 +7,25 @@
 read.shape <- function(filen, dbf.data=TRUE, verbose=TRUE, repair=FALSE) {
   filen <- path.expand(filen)
   .Deprecated("", package="maptools", msg="use readShapeSpatial:\nobjects other than Spatial objects defined in the sp package are deprecated")
+  if (length(grep("\\.shp$", tolower(filen))) == 0)
+    filen <- paste(filen, "shp", sep=".")
   shinfo <- getinfo.shape(filen)
   if (dbf.data) {
 #    library(foreign)
-    df <- read.dbf(filen)
+# filename wrong assumption BDR 100403
+#    df <- read.dbf(filen)
+    bn <- basename(filen)
+    dn <- dirname(filen)
+    sbn <- strsplit(bn, "\\.")[[1]]
+    lsbn <- length(sbn)
+    if (lsbn > 1 && tolower(sbn[lsbn]) == "shp") sbn[lsbn] <- "dbf"
+    filen1 <- paste(sbn, collapse=".")
+    if (length(grep("\\.dbf$", filen1)) == 0)
+        filen1 <- paste(filen1, "dbf", sep=".")
+    if (length(dn) > 0) {
+        filen1 <- paste(dn, filen1, sep=.Platform$file.sep)
+    }
+    df <- read.dbf(filen1)
     ndf <- as.integer(nrow(df))
   } else ndf <- as.integer(NA)
   if (shinfo[[2]] == 8) {
